<?xml version="1.0" encoding="UTF-8"?>
<!-- 
 Licensed Materials - Property of IBM
 Restricted Materials of IBM  - Modification is prohibited.

 (c) Copyright IBM Corporation 2004, 2006. All Rights Reserved. 

 Note to U.S. Government Users Restricted Rights:  Use, duplication or
 disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
-->
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:xalan="http://xml.apache.org/xalan"
	exclude-result-prefixes="xalan">
	
<xsl:output method="html" xalan:omit-meta-tag="yes" xalan:use-url-escaping="no"/>
	
<xsl:param name="tool_mentor"/>
<xsl:param name="toolmentor"/>
<xsl:param name="rpw_artifact"/>
<xsl:param name="artifact"/>
<xsl:param name="outcome"/>
<xsl:param name="deliverable"/>
<xsl:param name="task"/>
<xsl:param name="role"/>
<xsl:param name="guidance"/>
<xsl:param name="activity"/>
<xsl:param name="workflow_detail"/>
<xsl:param name="general_content"/>
<xsl:param name="other_rpw"/>

<!-- Key for Muenchian grouping which literally means: -->
<!-- Create a key with the name "typeGroup" on all the tags "SearchHit" and group them by "type" -->
<xsl:key name="typeGroup" match="SearchHit" use="@type" />

<xsl:template match="/SearchResult">
	<xsl:variable name="search_result_css"><xsl:value-of select="@css"/></xsl:variable>
	<xsl:variable name="search_result_js"><xsl:value-of select="@js"/></xsl:variable>
	<xsl:variable name="plus_img"><xsl:value-of select="@plus"/></xsl:variable>
	<xsl:variable name="minus_img"><xsl:value-of select="@minus"/></xsl:variable>
	<xsl:variable name="font_name"><xsl:value-of select="@fontname"/></xsl:variable>
	<xsl:variable name="font_size"><xsl:value-of select="@fontsize"/></xsl:variable>
	<html>
		<head>
			<link rel="StyleSheet" href="{$search_result_css}" type="text/css"/>
			<script language="JavaScript" type="text/javascript" src="{$search_result_js}"></script>
		</head>
		<body style="margin: 2; font-size: {$font_size}; font-family: {$font_name};">			
			<xsl:for-each select="SearchHit[generate-id()=generate-id(key('typeGroup', @type)[1])]">
				<!--  <xsl:sort select="@type" order="descending"/>  -->
				<!--  <xsl:sort select="number(n1:position)" data-type="number"/>  -->
				<xsl:sort select="@position"/>
				<div class="type visible" > 			 		
			 		<xsl:choose>
						<xsl:when test="@type = 'toolmentor' or @type = 'tool_mentor' or @type = 'other_rpw'">
							<input type="hidden" id="hiddenId" value="1" />
							<img id="expandId" class="expander" onclick="expandGroup(event);" onmouseover="style.cursor='pointer';" alt="" src="{$minus_img}"/>
						</xsl:when>
						<xsl:otherwise>
							<input type="hidden" id="hiddenId" value="0" />
							<img id="expandId" class="expander" onclick="expandGroup(event);" onmouseover="style.cursor='pointer';" alt="" src="{$plus_img}"/>
						</xsl:otherwise>
					</xsl:choose>					
    				<xsl:variable name="groupTypeText" select="@type"/>
    				<a href="#" class="grouptype" onfocus="expandGroupForTabKey(event);" onclick="javascript:disableAnchor(this, true)">
    				<xsl:choose>
						<xsl:when test="@type = 'tool_mentor'">
							<xsl:value-of select="$tool_mentor" />
						</xsl:when>
						<xsl:when test="@type = 'toolmentor'">
							<xsl:value-of select="$toolmentor" />
						</xsl:when>
						<xsl:when test="@type = 'rpw_artifact'">
							<xsl:value-of select="$rpw_artifact" />
						</xsl:when>
						<xsl:when test="@type = 'artifact' or @type = 'outcome' or @type = 'deliverable'">
							<xsl:value-of select="$artifact" />
						</xsl:when>
						<xsl:when test="@type = 'task'">
							<xsl:value-of select="$task" />
						</xsl:when>
						<xsl:when test="@type = 'role'">
							<xsl:value-of select="$role" />
						</xsl:when>
						<xsl:when test="@type = 'guidance'">
							<xsl:value-of select="$guidance" />
						</xsl:when>
						<xsl:when test="@type = 'activity'">
							<xsl:value-of select="$activity" />
						</xsl:when>
						<xsl:when test="@type = 'workflow_detail'">
							<xsl:value-of select="$workflow_detail" />
						</xsl:when>
						<xsl:when test="@type = 'general_content'">
							<xsl:value-of select="$general_content" />
						</xsl:when>
						<xsl:when test="@type = 'other_rpw'">
							<xsl:value-of select="$other_rpw" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="@type" />
						</xsl:otherwise>
					</xsl:choose>
					</a>
					<xsl:text> </xsl:text>(<xsl:value-of select="count(key('typeGroup', @type))"/>)<br/>					
                	<xsl:apply-templates select="key('typeGroup', @type)">
                		<xsl:sort select="@title"/>
                	</xsl:apply-templates>
                </div>            
            </xsl:for-each>             
		</body>
	</html>
</xsl:template>

<xsl:template match="SearchHit">
	<xsl:variable name="image" select="@image"/>
	<xsl:variable name="url" select="@url"/>
	<xsl:variable name="title" select="@title"/>
	<xsl:variable name="visibility">
		<xsl:choose>
			<xsl:when test="@type = 'toolmentor' or @type = 'tool_mentor' or @type = 'other_rpw'">result visible</xsl:when>
			<xsl:otherwise>result invisible</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>	
	<div class="{$visibility}">		
		<span class="image"><img alt="" src="{$image}"/></span>
		<a href="{$url}"><xsl:value-of select="$title"/></a><br/>
	</div>
</xsl:template>
</xsl:stylesheet>